@@ -11,6 +11,7 @@ from django.conf.urls.defaults import patterns, url
 from django.template.defaultfilters import slugify
 from django.http import HttpResponse
 from django.utils.html import escape
+from django.utils.encoding import iri_to_uri
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
@@ -336,10 +337,9 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         Intercept add page and redirect to form.
         """
         apps = MembershipApp.objects.filter(
-                                status=True,
-                                status_detail__in=['published',
-                                                   'active']
-                                            )
+            status=True,
+            status_detail__in=['published', 'active'])
+
         count = apps.count()
         if count == 1:
             app = apps[0]
@@ -356,6 +356,25 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
                 reverse('admin:memberships_membershipapp_changelist')
             )
 
+    def response_change(self, request, obj):
+        """
+        When the change page is submitted we can redirect
+        to a URL specified in the next parameter.
+        """
+        POST_KEYS = request.POST.keys()
+        GET_KEYS = request.GET.keys()
+        NEXT_URL = iri_to_uri('%s') % request.GET.get('next')
+
+        do_next_url = (
+            not '_addanother' in POST_KEYS,
+            not '_continue' in POST_KEYS,
+            'next' in GET_KEYS)
+
+        if all(do_next_url):
+            return HttpResponseRedirect(NEXT_URL)
+
+        return super(MembershipDefaultAdmin, self).response_change(request, obj)
+
     def queryset(self, request):
         qs = super(MembershipDefaultAdmin, self).queryset(request)
         return qs.order_by('-application_approved_dt')
@@ -366,7 +385,8 @@ class MembershipDefaultAdmin(admin.ModelAdmin):
         """
         urls = super(MembershipDefaultAdmin, self).get_urls()
 
-        extra_urls = patterns('',
+        extra_urls = patterns(
+            u'',
             url("^approve/(?P<pk>\d+)/$",
                 self.admin_site.admin_view(self.approve),
                 name='membership.admin_approve'),
