@@ -21,6 +21,8 @@ from django.utils.safestring import mark_safe
 from django.utils.encoding import smart_str
 from django.db.models.fields import AutoField
 from django.db.models import ForeignKey, OneToOneField
+from django.core.urlresolvers import reverse
+from django.template.loader import render_to_string
 
 from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.perms.utils import has_perm
@@ -36,6 +38,7 @@ from tendenci.addons.memberships.models import (App,
 from tendenci.core.base.utils import normalize_newline
 from tendenci.apps.profiles.models import Profile
 from tendenci.apps.profiles.utils import make_username_unique, spawn_username
+from tendenci.core.emails.models import Email
 from tendenci.core.payments.models import PaymentMethod
 from tendenci.apps.entities.models import Entity
 
@@ -235,7 +238,8 @@ def membership_rows(user_field_list,
                     demographic_field_list,
                     membership_field_list,
                     foreign_keys,
-                    export_status_detail=''):
+                    export_status_detail='',
+                    cp_id=0):
     # grab all except the archived
     memberships = MembershipDefault.objects.filter(
                                 status=True
@@ -250,6 +254,10 @@ def membership_rows(user_field_list,
         else:
             memberships = memberships.filter(
                         status_detail=export_status_detail)
+    if cp_id:
+        memberships = memberships.filter(
+                        corp_profile_id=cp_id
+                                         )
 
     for membership in memberships:
         row_dict = {}
@@ -286,7 +294,9 @@ def get_obj_field_value(field_name, obj, is_foreign_key=False):
 
 def process_export(export_type='all_fields',
                    export_status_detail='active',
-                   identifier=''):
+                   identifier='',
+                   user_id=0,
+                   cp_id=0):
     from tendenci.core.perms.models import TendenciBaseModel
     if export_type == 'main_fields':
         base_field_list = []
@@ -352,9 +362,14 @@ def process_export(export_type='all_fields',
 
         fks = Set(user_fks + profile_fks + demographic_fks + membership_fks)
 
+    membership_ids_dict = dict(MembershipType.objects.all(
+                                    ).values_list('id', 'name'))
+
     if not identifier:
         identifier = int(ttime.time())
-    file_name_temp = 'export/memberships/%s_temp.csv' % identifier
+    file_name_temp = 'export/memberships/%s_%d_temp.csv' % (
+                                            identifier, cp_id)
+
     with default_storage.open(file_name_temp, 'wb') as csvfile:
         csv_writer = csv.writer(csvfile)
         csv_writer.writerow(title_list)
@@ -364,7 +379,8 @@ def process_export(export_type='all_fields',
                                         demographic_field_list,
                                         membership_field_list,
                                         fks,
-                                        export_status_detail):
+                                        export_status_detail,
+                                        cp_id):
             items_list = []
             for field_name in title_list:
                 item = row_dict.get(field_name)
@@ -379,14 +395,52 @@ def process_export(export_type='all_fields',
                         item = item.strftime('%H:%M:%S')
                     elif isinstance(item, basestring):
                         item = item.encode("utf-8")
+                    elif field_name == 'membership_type':
+                        # display membership type name instead of id
+                        item = membership_ids_dict[item]
                 items_list.append(item)
             csv_writer.writerow(items_list)
     # rename the file name
-    file_name = 'export/memberships/%s.csv' % identifier
+    file_name = 'export/memberships/%s_%d.csv' % (identifier, cp_id)
     default_storage.save(file_name, default_storage.open(file_name_temp, 'rb'))
     # delete the temp file
     default_storage.delete(file_name_temp)
 
+    # notify user that export is ready to download
+    [user] = User.objects.filter(id=user_id)[:1] or [None]
+    if user and user.email:
+        corp_profile = None
+        if cp_id:
+            from tendenci.addons.corporate_memberships.models import CorpProfile
+            [corp_profile] = CorpProfile.objects.filter(pk=cp_id)[:1] or [None]
+        download_url = reverse('memberships.default_export_download',
+                                     args=[identifier])
+        if cp_id:
+            download_url = '%s?cp_id=%s' % (download_url, cp_id)
+        site_url = get_setting('site', 'global', 'siteurl')
+        site_display_name = get_setting('site', 'global', 'sitedisplayname')
+        parms = {
+                 'download_url': download_url,
+                 'user': user,
+                 'site_url': site_url,
+                 'site_display_name': site_display_name,
+                 'export_status_detail': export_status_detail,
+                 'export_type': export_type,
+                 'corp_profile': corp_profile
+                 }
+
+        subject = render_to_string(
+                        'memberships/notices/export_ready_subject.html',
+                        parms)
+        subject = subject.strip('\n').strip('\r')
+        body = render_to_string('memberships/notices/export_ready_body.html',
+                                   parms)
+
+        email = Email(recipient=user.email,
+                      subject=subject,
+                      body=body)
+        email.send()
+
 
 def has_null_byte(file_path):
     f = default_storage.open(file_path, 'r')
